<span class="abx-output-icon abx-output-icon--env" title="Environment"><svg width="16" height="16" viewBox="0 0 24 24" aria-hidden="true" focusable="false" fill="none" stroke="currentColor" stroke-width="1.8" stroke-linecap="round" stroke-linejoin="round"><rect x="3" y="4.5" width="18" height="15" rx="2"/><path d="M3 9h18"/><path d="M7 12l2.5 2.5L7 17"/><path d="M12 17h5"/></svg></span>
